function varargout = wantcache(varargin)
% WANTCACHE -- Return or update Expint cache desirabilty status
%
% SYNOPSIS:
%       wantcache(stat)
%   b = wantcache
%
% PARAMETERS:
%   stat - New cache disirability status.  OPTIONAL.
%          Used as a boolean flag stating whether or not caching is
%          wanted.
%
%          Possible values are
%            - FALSE, 0, 'false', 'off', 'no', 'n' -- caching unwanted
%            - anything else                       -- caching wanted
%
%          Case is insignificant in string values.
%
% RETURNS:
%   b   - Boolean value indicating whether or not caching is wanted.
%         OPTIONAL.
%
% SEE ALSO:
%   TRUE, FALSE, PHIPADE, ONEEZ2.

% This file is part of the 'Expint'-package,
% see http://www.math.ntnu.no/num/expint/
%
% $Revision: 1.3 $  $Date: 2005/05/06 19:54:05 $

error(nargchk(0, 1, nargin));
error(nargoutchk(0, 1, nargout));

if all([nargin, nargout] == 0),
   error('EXPINT:wantcache:einval', 'Incorrect usage, see documentation');
end

persistent state;

if isempty(state), state = true; end

if nargin > 0,
   if islogical(varargin{1}),
      state = varargin{1};
   else
      switch lower(varargin{1}),
      case { 0, 'false', 'off', 'no', 'n' },
         state = false;
      otherwise
         state = true;
      end
   end
end

if nargout > 0,
   varargout{1} = state;
end
