function Nr = burgers_N(U, t, problem)
% BURGERS_N -- Non-linear term of BURGERS equation.
%
% SYNOPSIS:
%   Nr = burgers_N(U, problem);
% 
% DESCRIPTION:
%   Evaluates the non-linear term of the semi-discretised
%   Kuramoto--Sivashinsky equation at a point `U'.
%
% PARAMETERS:
%   U       - Evaluation point.
%   problem - Problem dependent parameters.  Defined by BURGERS.
%
% RETURNS:
%   Nr      - Value of non-linear term at `U'.
%
% SEE ALSO:
%   BURGERS, INTEGRATOR.

% This file is part of the 'Expint'-package,
% see http://www.math.ntnu.no/num/expint/
%
% $Revision: 1.3 $  $Date: 2005/05/02 14:09:13 $

Nr = -0.5i * problem.k .* fft(real(ifft(U)) .^ 2);
